﻿using System.ComponentModel.DataAnnotations;
using Connected.Annotations;
using Connected.Common.Documents;
using Connected.ServiceModel;

namespace Connected.Logistics.Documents.Receive;
public sealed class InsertReceivePostingDocumentArgs : InsertDocumentArgs
{
	[MinValue(1)]
	public int Document { get; set; }
}

public sealed class UpdateReceivePostingDocumentArgs : UpdateDocumentArgs<int>
{
	[MinValue(0)]
	public int ItemCount { get; set; }
	[MinValue(0)]
	public int OpenItemCount { get; set; }
}

/// <summary>
/// The arguments used when inserting a new <see cref="IReceivePostingItem"/> item
/// via <see cref="IReceiveDocumentService"/> service.
/// </summary>
public class InsertReceivePostingItemArgs : Dto
{
	/// <summary>
	/// The id of the <see cref="IReceivePostingDocument"/> document. 
	/// Must exists in the storage.
	/// </summary>
	[MinValue(1)]
	public int Document { get; set; }

	[MinValue(1)]
	public int Location { get; set; }

	[MinValue(0)]
	public float Quantity { get; set; }

	[MinValue(1)]
	public long? Serial { get; set; }
}

public class InsertReceivePlannedItemArgs : Dto
{
	[MinValue(1)]
	public int Document { get; set; }

	[MinValue(0)]
	public float Quantity { get; set; }

	public string Entity { get; set; }
	public string EntityId { get; set; }
}

public class UpdateReceivePlannedItemArgs : PrimaryKeyArgs<long>
{
	[MinValue(0)]
	public float PostedQuantity { get; set; }
}

public class SelectReceivePlannedItemArgs : Dto
{
	[MinValue(1)]
	public int Document { get; set; }
	[Required, MaxLength(128)]
	public string Entity { get; set; } = default!;

	[Required, MaxLength(128)]
	public string EntityId { get; set; } = default!;
}

