﻿using Connected.Annotations;
using Connected.ServiceModel;

namespace Connected.Logistics.Stock;
/// <summary>
/// Represents the arguments when updating the stock items.
/// </summary>
public sealed class UpdateStockArgs : Dto
{
	/// <summary>
	/// The serial number of the item.
	/// </summary>
	[MinValue(1)]
	public long Serial { get; set; }
	/// <summary>
	/// The warehouse location where the items are stored.
	/// </summary>

	[MinValue(1)]
	public int Location { get; set; }
	/// <summary>
	/// The changed quantity. Can be a positive or negative
	/// value.
	/// </summary>
	public float Quantity { get; set; }
}

public sealed class QueryStockItemsArgs : PrimaryKeyArgs<long>
{
	[MinValue(1)]
	public int Location { get; set; }
	/// <summary>
	/// The optional serial number.
	/// </summary>
	public long? Serial { get; set; }
}